<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>AutoUpdater</name>
    <message>
        <source>No ssl configuration!
OpenSSL might not be installed.</source>
        <translation>¡SSL no configurado!
OpenSSL podría no estar instalado.</translation>
    </message>
    <message>
        <source>Failed to save the Birdtray installer:
</source>
        <translation>Fallo al salvar el instalador de Birdtray:
</translation>
    </message>
    <message>
        <source>Failed to download the Birdtray installer:
</source>
        <translation>Fallo al descargar el instaladro de Birdtray:
</translation>
    </message>
    <message>
        <source>Installer download failed</source>
        <translation>La descarga del instaldor ha fallado</translation>
    </message>
    <message>
        <source>Update failed</source>
        <translation>La actualización ha fallado</translation>
    </message>
    <message>
        <source>Failed to start the Birdtray installer.</source>
        <translation>Fallo al iniciar el instaldor de Birdtray.</translation>
    </message>
</context>
<context>
    <name>BirdtrayApp</name>
    <message>
        <source>Display the contents of the given mork database.</source>
        <translation>Mostrar el contenido de la base de datos de mork.</translation>
    </message>
    <message>
        <source>databaseFile</source>
        <translation>databaseFile</translation>
    </message>
    <message>
        <source>Decode an IMAP Utf7 string.</source>
        <translation>Descodificar una cadena Utf7 de IMAP.</translation>
    </message>
    <message>
        <source>string</source>
        <translation>cadena</translation>
    </message>
    <message>
        <source>Show the settings.</source>
        <translation>Mostrar las configuraciones.</translation>
    </message>
    <message>
        <source>Reset the settings to the defaults.</source>
        <translation>Reponer las configuraciones por defecto.</translation>
    </message>
    <message>
        <source>Toggle the Thunderbird window.</source>
        <translation>Fijar la ventana de Thunderbird.</translation>
    </message>
    <message>
        <source>Show the Thunderbird window.</source>
        <translation>Mostrar la ventana de Thunderbird.</translation>
    </message>
    <message>
        <source>Hide the Thunderbird window.</source>
        <translation>Ocultar la ventana de Thunderbird.</translation>
    </message>
    <message>
        <source>Write log to a file.</source>
        <translation>Escribir el registro en un fichero.</translation>
    </message>
    <message>
        <source>A free system tray notification for new mail for Thunderbird.</source>
        <translation>Un sistema libre de notificación para la bandeja el sistema para nuevos correos de Thunderbird.</translation>
    </message>
    <message>
        <source>file</source>
        <translation>fichero</translation>
    </message>
    <message>
        <source>Sorry, the system tray cannot be controlled by this add-on on your operating system.</source>
        <translation>Lo sentimos, la bandeja del sistema no puede ser controlado a través de este complemento en su sistema operativo.</translation>
    </message>
</context>
<context>
    <name>DialogAddEditNewEmail</name>
    <message>
        <source>&quot;New Email&quot; Entry</source>
        <translation>Entrada de &quot;Nuevo correo&quot;</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>(Optional) Prefilled fields</source>
        <translation>(Opcional) Campos prellenados</translation>
    </message>
    <message>
        <source>Email subject:</source>
        <translation>Asunto del correo:</translation>
    </message>
    <message>
        <source>Email message text:</source>
        <translation>Texto del mensaje del correo:</translation>
    </message>
    <message>
        <source>Email recipient:</source>
        <translation>Dirección del destinatario:</translation>
    </message>
    <message>
        <source>No name specified</source>
        <translation>Nombre no especificado</translation>
    </message>
    <message>
        <source>The name cannot be empty.</source>
        <translation>El nombre no puede estar vacío.</translation>
    </message>
</context>
<context>
    <name>DialogLogOutput</name>
    <message>
        <source>Debug log viewer</source>
        <translation>Visor del registro de depuración</translation>
    </message>
</context>
<context>
    <name>DialogSettings</name>
    <message>
        <source>Birdtray Settings</source>
        <translation>Preferencias de Birdtray</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>New Mail Notification</source>
        <translation>Notificación de nuevo correo</translation>
    </message>
    <message>
        <source>Show unread count</source>
        <translation>Mostrar contador de no leídos</translation>
    </message>
    <message>
        <source>Different icon when unread:</source>
        <translation>Icono diferente para no leídos:</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Fastest</source>
        <translation>Más rápido</translation>
    </message>
    <message>
        <source>Icon (Ctrl-click to reset):</source>
        <translation>Icono (Ctrl-pulsar para reiniciar):</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This notification color will be used when more than one monitored account has unread emails.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;El color de esta notificación será usado cuando más de una cuenta supervisada tenga correos sin leer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Multiple notification color:</source>
        <translation>Color de notificación múltiple:</translation>
    </message>
    <message>
        <source>Blinking speed:</source>
        <translation>Velocidad del parpadeo:</translation>
    </message>
    <message>
        <source>Font style:</source>
        <translation>Estilo de la fuente:</translation>
    </message>
    <message>
        <source>Bold:</source>
        <translation>Negrita:</translation>
    </message>
    <message>
        <source>Notification border color:</source>
        <translation>Color del borde de la notificación:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Ancho:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Monitoring</source>
        <translation>Supervisar</translation>
    </message>
    <message>
        <source>Accounts to monitor</source>
        <translation>Cuentas a supervisar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Allow ignoring the current unread email counter</source>
        <translation>Permitir ignorar la actual contador de correos no leídos</translation>
    </message>
    <message>
        <source>Hiding</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <source>Launching and Hiding</source>
        <translation>Lanzar y ocultar</translation>
    </message>
    <message>
        <source>Start Thunderbird when Birdtray starts</source>
        <translation>Iniciar Thunderbird cuando Birdtray inicie</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;When both Thunderbird and Birdtray are set to start with the operating system, this usually results in two copies of Thunderbird being launched. Here you can add a delay before Thunderbird is launched, to prevent this.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Cuando Thunderbird y Birdtray son iniciadas por el sistema operativo, normalmente hace que dos instancias de Thunderbird sean lanzadas. Puedes añadir un retraso antes de que Thunderbird sea lanzado, para prevenirlo.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> second delay</source>
        <translation> segundo retraso</translation>
    </message>
    <message>
        <source>with a </source>
        <translation>con un </translation>
    </message>
    <message>
        <source>and hide it</source>
        <translation>y ocultarlo</translation>
    </message>
    <message>
        <source>Terminate Thunderbird when quitting Birdtray</source>
        <translation>Finalizar Thunderbird cuando salga de Birdtray</translation>
    </message>
    <message>
        <source>Hide/show Thunderbird window when clicking on tray icon</source>
        <translation>Ocultar/mostrar la ventana de Thunderbird cuando pulse en el icono de la bandeja del sistema</translation>
    </message>
    <message>
        <source>Hide Thunderbird window when it is minimized</source>
        <translation>Ocultar la ventana de Thunderbird cuando esté minimizada</translation>
    </message>
    <message>
        <source>Show red X in tray icon if Thunderbird is not running</source>
        <translation>Mostrar una X roja en el icono de la bandeja del sistema si Thunderbird no esta en ejecución</translation>
    </message>
    <message>
        <source>Restart Thunderbird if it was closed</source>
        <translation>Reabrir Thunderbird si ha sido cerrado</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>Nuevo correo</translation>
    </message>
    <message>
        <source>Enable New Email submenu</source>
        <translation>Habilitar submenú de nuevo correo</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <source>Please do not change these settings unless you understand what you&apos;re doing.</source>
        <translation>Por favor, no cambie estas preferencias a menos que entienda lo que está haciendo.</translation>
    </message>
    <message>
        <source>Thunderbird window name pattern:</source>
        <translation>Modelo de nombre de la ventana de Thunderbird:</translation>
    </message>
    <message>
        <source>Minimum notification font size:</source>
        <translation>Tamaño de la fuente de notificación mínimo:</translation>
    </message>
    <message>
        <source> points</source>
        <translation> puntos</translation>
    </message>
    <message>
        <source>When blinking, use the fade-in/fade-out transition (increases CPU use!)</source>
        <translation>Cuando parpadee, usar transición fundirse/aparecer (¡Incrementa el uso de CPU!)</translation>
    </message>
    <message>
        <source>Make the system tray icon</source>
        <translation>Mostrar el icono de la bandeja del sistema</translation>
    </message>
    <message>
        <source>Check for new updates on startup</source>
        <translation>Comprobar actualizaciones en el arranque</translation>
    </message>
    <message>
        <source>Check now</source>
        <translation>Comprobar ahora</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>Version check failed</source>
        <translation>La comprobación de la versión ha fallado</translation>
    </message>
    <message>
        <source>Failed to check for a new Birdtray version:
</source>
        <translation>Fallo en la comprobación de la nueva versión de Birdtray:
</translation>
    </message>
    <message>
        <source>Checking...</source>
        <translation>Comprobando...</translation>
    </message>
    <message>
        <source>Choose the new icon</source>
        <translation>Escoger el icono nuevo</translation>
    </message>
    <message>
        <source>Images (*.png *.svg *.svgz)</source>
        <translation>Imágenes (*.png *.svg *.svgz)</translation>
    </message>
    <message>
        <source>Invalid icon</source>
        <translation>Icono no válido</translation>
    </message>
    <message>
        <source>Could not load the icon from this file.</source>
        <translation>No se puede cargar el icono de este fichero.</translation>
    </message>
    <message>
        <source>Thunderbird command line:</source>
        <translation>Linea de comando de Thunderbird:</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This is the full command-line (with arguments) which will be used to start Thunderbird. Arguments are space-separated, but spaces in quotes are allowed, i.e. something like &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt; will work.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Esta es la linea de comando completa (con parámetros) que será usada par iniciar Thunderbird. Los parámetros son separados mediante espacios, pero se permiten espacios entre comillas, como por ejemplo &lt;span style=&quot; font-weight:600;&quot;&gt;&amp;quot;C:\Program Files\tb.exe&amp;quot; --profile test&lt;/span&gt; funcionará.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Ignore all unread email that are present when Birdtray starts. Only new emails will be taken into account by the unread counter.</source>
        <translation>Ignorar todos los correos no leidos que estén presentes cuando Birdtray se inice. Solo los nuevos correos seran tenidos en cuenta por el contador de no leídos.</translation>
    </message>
    <message>
        <source>opaque when new mail is present,</source>
        <translation>opaco cuando haya nuevos correos,</translation>
    </message>
    <message>
        <source>hide it if no new mail is present.</source>
        <translation>ocultar si no hay nuevos correos.</translation>
    </message>
    <message>
        <source>Choose one or more MSF files</source>
        <translation>Elegir uno o mas ficheros MSF</translation>
    </message>
    <message>
        <source>Mail Index (*.msf)</source>
        <translation>Indice de Correo (*.msf)</translation>
    </message>
    <message>
        <source>No new updates found</source>
        <translation>No se han encontrado nuevas actualizaciones</translation>
    </message>
    <message>
        <source>Show log window</source>
        <translation>Mostrar la ventana de registro</translation>
    </message>
    <message>
        <source>Force index file re-read every</source>
        <translation>Forzar la relectura de cada fichero de índices</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
    <message>
        <source>Translations are powered by the community:</source>
        <translation>Idiomas soportados por la comunidad:</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Traductores</translation>
    </message>
    <message>
        <source>Active maintainers</source>
        <translation>Mantenedores activos</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation>Contribuyentes</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If this box is checked, the Birdtray icon will show the number of unread emails.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;If it is unchecked, no count will be shown, and you will only know about unread emails because of the blinking or different icon, depending on your settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Si es seleccionado, el icono de Birdtray mostrará el numero de corresos no leídos.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;Si es deseleccionado, ningún contador será mostrado, y sólo se sabrá que existe un mensaje no leído por el parpadeo o el direrente color del icono, dependiendo de su configuración.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select mail folders for watching.&lt;br/&gt;&lt;br/&gt;If the dialog doesn&apos;t show your folder, &lt;i&gt;Ctrl + Shift click&lt;/i&gt; to open a file selection dialog that allows adding any mork file.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unread change cmd:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not load the icon from this file. Try loading the icon in an image editing tool and saving it in a different format.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This changes the font thickness, i.e. makes the font bold.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Cambia el grosor de la fuente, por ejemplo, la hace negrita.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If not empty, this command will be invoked every time the unread counter changes (including when it becomes zero). It is invoked via shell, as-is, with %NEW% replaced by the new unread count value and %OLD% replaced with the old unread count value (which may be the same as new).&lt;/p&gt;&lt;p&gt;Most users don&apos;t need this functionality and should leave it empty.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Check for new updates when Birdtray starts.</source>
        <translation>Comprobar actualizaciones cuando bridtray se inicie.</translation>
    </message>
    <message>
        <source>Check for a new Birdtray version.</source>
        <translation>Comprobar si existe una nueva versión de Birdtray.</translation>
    </message>
    <message>
        <source>Support non-NETWM compliant WMs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your desktop manager is not fully NETWM compliant, you may need to check this checkbox so it can detect Thunderbird window and is able to minimise and hide it.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When hiding Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When showing Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If enabled, this option adds the &amp;quot;Ignore currently unread emails&amp;quot; action to the context menu. This action allows you to ignore the emails which are currently unread. Birdtray would then pretend there are no unread emails left, and would only show new emails over the ignored count.&lt;/p&gt;&lt;p&gt;&lt;br/&gt;For example, if there were 10 unread emails, and you clicked on &amp;quot;Ignore&amp;quot; action, Birdtray will show no unread email indicator as long as unread email count remains at 10. Once new email is received and you have 11 total unread emails, Birdtray will show the new email count as 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Si se habilita, esta opción añade la acción de &amp;quot;Ignorar correos no leíodos actualmente&amp;quot; al menú contextual. Esta acción le permite ignorar los corresos que actualmente son no leídos&lt;/p&gt;&lt;p&gt;&lt;br/&gt;Por ejemplo, si hay 10 correos no leidos, y pulsa en &amp;quot;Ignorar&amp;quot;, Birdtray mostraŕa el indicador de mensajes no leidos mientras el contador de mensajes no leídos permanece en 10. Una vez que un correo nuevo es recibido y tiene 11 correos no leídos totales, Bridtray mostrará el contador de correos nuevos como 1.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Start Thunderbird by clicking on the tray icon if it was closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When detecting a change, wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> milliseconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>before updating the unread counter.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird process name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Birdtray version [VERSION] compiled at [DATE] using Qt [QT_VERSION].&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray is FREE SOFTWARE, which is licensed under General Public License v3. To clarify further, you can use it for any purpose, including commercial, without paying anything. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;To ask for help, request a feature or report a bug use the &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;Github project page&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;For those of you who appreciate my work on Birdtray, which is being developed in my free time, you can do it here: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Thank you for your continuous support!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-weight:600;&quot;&gt;Versión Birdtray [VERSION] compilada en [DATE] (Qt [QT_VERSION]).&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Copyright (C) 2018 by George Yunaev, &lt;/span&gt;&lt;a href=&quot;mailto:gyunaev@ulduzsoft.com&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;gyunaev@ulduzsoft.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Birdtray es SORTWARE LIBRE, cuya licencia está bajo General Public License v3. Para mayor aclaración, puede usarlo para cualquier proposito, incluido el comercial, sin pagar nada. &lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Para pedir ayuda, solicitar una función o reportar un error, use &lt;/span&gt;&lt;a href=&quot;https://github.com/gyunaev/birdtray&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;página del proyecto de Github &lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;Para aquellos que aprecian mi trabajo en Birdtray, que ha sido desarrollado en mi tiempo libre, puede hacerlo aquí: &lt;/span&gt;&lt;a href=&quot;https://paypal.me/ulduzsoft&quot;&gt;&lt;span style=&quot; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;https://paypal.me/ulduzsoft&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:8pt; text-decoration: underline; color:#2980b9;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;¡Gracias por su apoyo continuo!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <source>Fatal</source>
        <translation>Fatal</translation>
    </message>
    <message>
        <source>Fatal error: %1

Log file is written into file %2</source>
        <translation>Error fatal: %1

El fichero de registro fue escrito en el archivo %2</translation>
    </message>
    <message>
        <source>Failed to open log file %1: %2</source>
        <translation>Fallo al abrir el fichero de registro %1: %2</translation>
    </message>
</context>
<context>
    <name>MailAccountDialog</name>
    <message>
        <source>No folder selected</source>
        <translation>Niguna carpeta seleccionada</translation>
    </message>
    <message>
        <source>No mail folder was selected to monitor.
Do you want to continue?</source>
        <translation>Ninguna capeta de correo ha sido seleccionada en el controlador
¿Quiere continuar?</translation>
    </message>
    <message>
        <source>Select Accounts</source>
        <translation>Seccionar cuentas</translation>
    </message>
    <message>
        <source>Select the directory that contains the Thunderbird profiles.</source>
        <translation>Seleccionar el directorio que contiene los perfiles de Thunderbird.</translation>
    </message>
    <message>
        <source>Thunderbird Profiles Directory</source>
        <translation>Directorio de Perfiles de Thunderbird</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Select the mail accounts you want to monitor.</source>
        <translation>Seleccione las cuentas de correo que quiere controlar.</translation>
    </message>
    <message>
        <source>Email Folder</source>
        <translation>Carpeta de correo</translation>
    </message>
    <message>
        <source>Notification Color</source>
        <translation>Color de la notificación</translation>
    </message>
    <message>
        <source>If you monitor multiple folders, the default notification color is used to show the sum of all unread mails.</source>
        <translation>Si controla multiples carpetas, el color de la notificación por defecto se usará para mostrar la suma de todos los correos no leídos.</translation>
    </message>
    <message>
        <source>%1 (Profile)</source>
        <translation>%1 (Perfil)</translation>
    </message>
    <message>
        <source>No mail profiles were found.
Please make sure you selected the correct profiles directory.</source>
        <translation>No se han encontrado perfiles de correo
Por favor, asegúrese que ha seleccionado el directorio de perfiles correcto.</translation>
    </message>
    <message>
        <source>Choose the Thunderbird profiles path</source>
        <translation>Elegir la ruta de perfiles de Thunderbird</translation>
    </message>
</context>
<context>
    <name>ModelAccountTree</name>
    <message>
        <source>Account</source>
        <translation>Cuenta</translation>
    </message>
    <message>
        <source>Notification color</source>
        <translation>Color de notificación</translation>
    </message>
</context>
<context>
    <name>ModelNewEmails</name>
    <message>
        <source>Menu entry item</source>
        <translation>Elemento de entrada del menú</translation>
    </message>
</context>
<context>
    <name>MorkParser</name>
    <message>
        <source>Couldn&apos;t open file: </source>
        <translation>No se pudo abrir el fichero: </translation>
    </message>
    <message>
        <source>Unsupported version.</source>
        <translation>Versión no soportada.</translation>
    </message>
    <message>
        <source>Invalid format.</source>
        <translation>Formato inválido.</translation>
    </message>
    <message>
        <source>Parsing error.</source>
        <translation>Error analizando.</translation>
    </message>
    <message>
        <source>Unexpected EOF.</source>
        <translation>EOF inesperado.</translation>
    </message>
    <message>
        <source>Invalid comment.</source>
        <translation>Comentario invalido.</translation>
    </message>
    <message>
        <source>Format error.</source>
        <translation>Error de formato.</translation>
    </message>
    <message>
        <source>Unexpected end of group.</source>
        <translation>Fin de grupo inesperado.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Could not save the settings</source>
        <translation>No se pudieron grabar las configuraciones</translation>
    </message>
    <message>
        <source>Could not save the settings into file %1:
%2</source>
        <translation>No puudo grabarse las configuraciones en el fichero %1:
%2</translation>
    </message>
    <message>
        <source>Sqlite based accounts migrated</source>
        <translation>Cuentas basadas en Sqlite cambiadas</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail folders using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser, but some configured mail folders could not be found.</source>
        <translation>Tenía configurado el control de una o más carpetas de correos usando el analizador de Sqlite. Este método ha sido eliminado. Tus configuraciones han sido cambiadas al analizador Mork, pero algunas carpetas de correo configurada podría no ser encontrada.</translation>
    </message>
    <message>
        <source>You had configured monitoring of one or more mail accounts using the Sqlite parser. This method has been removed. Your configurations has been migrated to the Mork parser. Please verify that all accounts were mapped correctly.</source>
        <translation>Tenía configurado el control de una o más carpetas de correos usando el analizador de Sqlite. Este método ha sido eliminado. Por favor, verifique si todas sus cuentas fueron correctamente mapeadas.</translation>
    </message>
    <message>
        <source>Cannot load default system tray icon.</source>
        <translation>No se pudo leer el icono de la bandeja del sistema por defecto.</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Would you like to set up Birdtray?</source>
        <translation>¿Desea configurar Birdtray?</translation>
    </message>
    <message>
        <source>You have not yet configured any email folders to monitor. Would you like to do it now?</source>
        <translation>No tiene todavía cofigurado ninguna capeta de correo a controlar. ¿Desea hacerlo ahora?</translation>
    </message>
    <message>
        <source>Show Thunderbird</source>
        <translation>Mostrar Thunderbird</translation>
    </message>
    <message>
        <source>Hide Thunderbird</source>
        <translation>Ocultar Thunderbird</translation>
    </message>
    <message>
        <source>New Email</source>
        <translation>Nuevo correo</translation>
    </message>
    <message>
        <source>Blank</source>
        <translation>Vacio</translation>
    </message>
    <message>
        <source>New Email Message</source>
        <translation>Nuevo mensaje de correo</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 minutos</translation>
    </message>
    <message>
        <source>10 minutes</source>
        <translation>10 minutos</translation>
    </message>
    <message>
        <source>30 minutes</source>
        <translation>30 minutos</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation>1 hora</translation>
    </message>
    <message>
        <source>4 hours</source>
        <translation>4 horas</translation>
    </message>
    <message>
        <source>Snooze for ...</source>
        <translation>Silenciar durante ...</translation>
    </message>
    <message>
        <source>Unsnooze</source>
        <translation>Posponer</translation>
    </message>
    <message>
        <source>Ignore unread emails</source>
        <translation>Ignorar correos no leídos</translation>
    </message>
    <message>
        <source>Settings...</source>
        <translation>Ajustes...</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Cannot start Thunderbird</source>
        <translation>No se pudo abrir Thunderbird</translation>
    </message>
    <message>
        <source>Error starting Thunderbird, because we could not attach to the updater:

%1</source>
        <translation>Erro al iniciar Thunderbird, porque no se pudo adjuntar el actualizador:

%1</translation>
    </message>
    <message>
        <source>Ignore unread emails (now %1)</source>
        <translation>Ignorar correos no leídos (now %1)</translation>
    </message>
    <message>
        <source>Error starting Thunderbird as &apos;%1 %2&apos;:

%3</source>
        <translation>Error iniciando Thunderbird como &apos;%1 %2&apos;:

%3</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>Advertencia: %1</translation>
    </message>
    <message>
        <source>Don&apos;t ask again</source>
        <translation>No preguntar de nuevo</translation>
    </message>
</context>
<context>
    <name>UnreadMonitor</name>
    <message>
        <source>Unable to watch %1 for changes.</source>
        <translation>Incapaz de mirar %1 para cambios.</translation>
    </message>
    <message>
        <source>Unable to read from %1.</source>
        <translation>Incapaz de leer desde %1.</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>Actualización de Birdtray</translation>
    </message>
    <message>
        <source>Current version:</source>
        <translation>Versión actual:</translation>
    </message>
    <message>
        <source>A new version of Birdtray is available.</source>
        <translation>Nueva versión de Birdtray disponible.</translation>
    </message>
    <message>
        <source>New version:</source>
        <translation>Nueva versión:</translation>
    </message>
    <message>
        <source>Download size:</source>
        <translation>Tamaño de la descarga:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
    <message>
        <source>Ignore this version</source>
        <translation>Ignorar esta versión</translation>
    </message>
    <message>
        <source>ca. %1 Mb</source>
        <translation>ca. %1 Mb</translation>
    </message>
    <message>
        <source>Update and restart</source>
        <translation>Actualizar y reiniciar</translation>
    </message>
</context>
<context>
    <name>UpdateDownloadDialog</name>
    <message>
        <source>Birdtray Update</source>
        <translation>Actualización de Birdtray</translation>
    </message>
    <message>
        <source>Downloading Birdtray update...</source>
        <translation>Descargando actualización de Birdtray...</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Segundo plano</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer...</source>
        <translation>Descargando instalador de Bridtray...</translation>
    </message>
    <message>
        <source>Download finished. Restart and update Birdtray?</source>
        <translation>Descarga finalizada. ¿Reiniciar y actualizar Birdtray?</translation>
    </message>
    <message>
        <source>Downloading Birdtray installer... (%1 Mb / %2 Mb).</source>
        <translation>Descargando instalador de Birdtray... (%1 Mb / %2 Mb).</translation>
    </message>
</context>
</TS>
